/*[process-shim]*/
(function(global, env) {
	// jshint ignore:line
	if (typeof process === "undefined") {
		global.process = {
			argv: [],
			cwd: function() {
				return "";
			},
			browser: true,
			env: {
				NODE_ENV: env || "development"
			},
			version: "",
			platform:
				global.navigator &&
				global.navigator.userAgent &&
				/Windows/.test(global.navigator.userAgent)
					? "win"
					: ""
		};
	}
})(
	typeof self == "object" && self.Object == Object
		? self
		: typeof process === "object" &&
		  Object.prototype.toString.call(process) === "[object process]"
			? global
			: window,
	"development"
);

/*[global-shim-start]*/
(function(exports, global, doEval) {
	// jshint ignore:line
	var origDefine = global.define;

	var get = function(name) {
		var parts = name.split("."),
			cur = global,
			i;
		for (i = 0; i < parts.length; i++) {
			if (!cur) {
				break;
			}
			cur = cur[parts[i]];
		}
		return cur;
	};
	var set = function(name, val) {
		var parts = name.split("."),
			cur = global,
			i,
			part,
			next;
		for (i = 0; i < parts.length - 1; i++) {
			part = parts[i];
			next = cur[part];
			if (!next) {
				next = cur[part] = {};
			}
			cur = next;
		}
		part = parts[parts.length - 1];
		cur[part] = val;
	};
	var useDefault = function(mod) {
		if (!mod || !mod.__esModule) return false;
		var esProps = { __esModule: true, default: true };
		for (var p in mod) {
			if (!esProps[p]) return false;
		}
		return true;
	};

	var hasCjsDependencies = function(deps) {
		return (
			deps[0] === "require" && deps[1] === "exports" && deps[2] === "module"
		);
	};

	var modules =
		(global.define && global.define.modules) ||
		(global._define && global._define.modules) ||
		{};
	var ourDefine = (global.define = function(moduleName, deps, callback) {
		var module;
		if (typeof deps === "function") {
			callback = deps;
			deps = [];
		}
		var args = [],
			i;
		for (i = 0; i < deps.length; i++) {
			args.push(
				exports[deps[i]]
					? get(exports[deps[i]])
					: modules[deps[i]] || get(deps[i])
			);
		}
		// CJS has no dependencies but 3 callback arguments
		if (hasCjsDependencies(deps) || (!deps.length && callback.length)) {
			module = { exports: {} };
			args[0] = function(name) {
				return exports[name] ? get(exports[name]) : modules[name];
			};
			args[1] = module.exports;
			args[2] = module;
		}
		// Babel uses the exports and module object.
		else if (!args[0] && deps[0] === "exports") {
			module = { exports: {} };
			args[0] = module.exports;
			if (deps[1] === "module") {
				args[1] = module;
			}
		} else if (!args[0] && deps[0] === "module") {
			args[0] = { id: moduleName };
		}

		global.define = origDefine;
		var result = callback ? callback.apply(null, args) : undefined;
		global.define = ourDefine;

		// Favor CJS module.exports over the return value
		result = module && module.exports ? module.exports : result;
		modules[moduleName] = result;

		// Set global exports
		var globalExport = exports[moduleName];
		if (globalExport && !get(globalExport)) {
			if (useDefault(result)) {
				result = result["default"];
			}
			set(globalExport, result);
		}
	});
	global.define.orig = origDefine;
	global.define.modules = modules;
	global.define.amd = true;
	ourDefine("@loader", [], function() {
		// shim for @@global-helpers
		var noop = function() {};
		return {
			get: function() {
				return { prepareGlobal: noop, retrieveGlobal: noop };
			},
			global: global,
			__exec: function(__load) {
				doEval(__load.source, global);
			}
		};
	});
})(
	{},
	typeof self == "object" && self.Object == Object
		? self
		: typeof process === "object" &&
		  Object.prototype.toString.call(process) === "[object process]"
			? global
			: window,
	function(__$source__, __$global__) {
		// jshint ignore:line
		eval("(function() { " + __$source__ + " \n }).call(__$global__);");
	}
);

/*analog-array@1.0.0#src/analog-array*/
define('analog-array', ['exports'], function (exports) {
    'use strict';
    Object.defineProperty(exports, '__esModule', { value: true });
    var getter = function getter(target, prop, receiver) {
        var propFloat = parseFloat(prop);
        if (!isNaN(propFloat)) {
            if (propFloat < 0) {
                return target[0];
            }
            var leftIndex = ~~propFloat;
            var lastIndex = target.length - 1;
            if (leftIndex >= lastIndex) {
                return target[lastIndex];
            }
            if (propFloat === leftIndex) {
                return target[propFloat];
            }
            return this.slide(target[leftIndex], target[leftIndex + 1], propFloat - leftIndex);
        } else {
            return Reflect.get(target, prop, receiver);
        }
    };
    var setter = function setter(target, prop, value, receiver) {
        if (prop === 'slide') {
            this.slide = value;
            return value;
        }
        return Reflect.set(target, prop, value, receiver);
    };
    function AnalogArray(array, slide) {
        this.array = array || [];
        this.slide = slide || AnalogArray.slideNumber;
        return new Proxy(this.array, {
            get: getter.bind(this),
            set: setter.bind(this)
        });
    }
    Object.assign(AnalogArray, {
        slideNumber: function slideNumber(from, to, amount) {
            return (to - from) * amount + from;
        },
        slideByte: function slideByte(from, to, amount) {
            var slid = AnalogArray.slideNumber(from & 255, to & 255, amount);
            return Math.round(Math.min(Math.max(slid, 0), 255));
        },
        slideColor: function slideColor(from, to, amount) {
            var sb = AnalogArray.slideByte;
            var fromLen = from.length;
            var color1 = parseInt(from.replace('#', ''), 16);
            var color2 = parseInt(to.replace('#', ''), 16);
            var res = sb(color1, color2, amount) | sb(color1 >>> 8, color2 >>> 8, amount) << 8 | sb(color1 >>> 16, color2 >>> 16, amount) << 16 | (fromLen > 7 ? sb(color1 >>> 24, color2 >>> 24, amount) << 24 : 0);
            var resStr = (res >>> 0).toString(16).padStart((fromLen | 1) ^ 1, '0');
            return fromLen & 1 ? '#' + resStr : resStr;
        }
    });
    exports.AnalogArray = AnalogArray;
    exports.default = AnalogArray;
});
/*[global-shim-end]*/
(function(global) { // jshint ignore:line
	global._define = global.define;
	global.define = global.define.orig;
}
)(typeof self == "object" && self.Object == Object ? self : (typeof process === "object" && Object.prototype.toString.call(process) === "[object process]") ? global : window);